@@ -26,6 +26,9 @@
 #include <tremor/ivorbisfile.h>
 #include <gst/bytestream/bytestream.h>
 
+GST_DEBUG_CATEGORY_STATIC (ivorbisfile_debug);
+#define GST_CAT_DEFAULT ivorbisfile_debug
+
 #define GST_TYPE_IVORBISFILE \
   (ivorbisfile_get_type())
 #define GST_IVORBISFILE(obj) \
@@ -40,10 +43,11 @@
 typedef struct _Ivorbisfile Ivorbisfile;
 typedef struct _IvorbisfileClass IvorbisfileClass;
 
-struct _Ivorbisfile {
+struct _Ivorbisfile
+{
   GstElement element;
 
-  GstPad *sinkpad,*srcpad;
+  GstPad *sinkpad, *srcpad;
   GstByteStream *bs;
 
   OggVorbis_File vf;
@@ -65,7 +69,8 @@ struct _Ivorbisfile {
   GstCaps *streaminfo;
 };
 
-struct _IvorbisfileClass {
+struct _IvorbisfileClass
+{
   GstElementClass parent_class;
 
 };
@@ -75,13 +80,13 @@ GType ivorbisfile_get_type (void);
 static GstPadTemplate *gst_vorbisdec_src_template, *gst_vorbisdec_sink_template;
 
 /* elementfactory information */
-GstElementDetails ivorbisfile_details = 
-{
+GstElementDetails ivorbisfile_details = {
   "Ogg Vorbis decoder",
   "Codec/Audio/Decoder",
   "Decodes OGG Vorbis audio using the Tremor vorbisfile API",
-  "Monty <monty@xiph.org>\n" 
-  "Wim Taymans <wim.taymans@chello.be>",
+  "Monty <monty@xiph.org>\n"
+      "Wim Taymans <wim.taymans@chello.be>\n"
+      "Amaury Jacquot <sxpert@esitcom.org>",
 };
 
 /* Ivorbisfile signals and args */
@@ -97,95 +102,40 @@ enum
   ARG_STREAMINFO
 };
 
-static void     gst_ivorbisfile_base_init       (gpointer g_class);
-static void
-		gst_ivorbisfile_class_init 	(IvorbisfileClass *klass);
-static void 	gst_ivorbisfile_init 		(Ivorbisfile *ivorbisfile);
+static void gst_ivorbisfile_base_init (gpointer g_class);
+static void gst_ivorbisfile_class_init (IvorbisfileClass * klass);
+static void gst_ivorbisfile_init (Ivorbisfile * ivorbisfile);
 
 static GstElementStateReturn
-		gst_ivorbisfile_change_state 	(GstElement *element);
+gst_ivorbisfile_change_state (GstElement * element);
 
-static const 
-GstFormat* 	gst_ivorbisfile_get_formats 	(GstPad *pad);
-static gboolean gst_ivorbisfile_src_convert 	(GstPad *pad, 
-		                                 GstFormat src_format, 
-						 gint64 src_value,
-		           			 GstFormat *dest_format, 
-						 gint64 *dest_value);
-static gboolean gst_ivorbisfile_sink_convert 	(GstPad *pad, 
-		            			 GstFormat src_format, 
-						 gint64 src_value,
-		            			 GstFormat *dest_format, 
-						 gint64 *dest_value);
-static const GstQueryType*
-		gst_ivorbisfile_get_query_types 	(GstPad *pad);
+static const GstFormat *gst_ivorbisfile_get_formats (GstPad * pad);
+static gboolean gst_ivorbisfile_src_convert (GstPad * pad,
+    GstFormat src_format,
+    gint64 src_value, GstFormat * dest_format, gint64 * dest_value);
+static gboolean gst_ivorbisfile_sink_convert (GstPad * pad,
+    GstFormat src_format,
+    gint64 src_value, GstFormat * dest_format, gint64 * dest_value);
+static const GstQueryType *gst_ivorbisfile_get_query_types (GstPad * pad);
 
-static gboolean gst_ivorbisfile_src_query 	(GstPad *pad, 
-		                                 GstQueryType type,
-		        	 		 GstFormat *format, 
-						 gint64 *value);
-static const 
-GstEventMask*	gst_ivorbisfile_get_event_masks 	(GstPad *pad);
-static gboolean gst_ivorbisfile_src_event 	(GstPad *pad, GstEvent *event);
+static gboolean gst_ivorbisfile_src_query (GstPad * pad,
+    GstQueryType type, GstFormat * format, gint64 * value);
+static const GstEventMask *gst_ivorbisfile_get_event_masks (GstPad * pad);
+static gboolean gst_ivorbisfile_src_event (GstPad * pad, GstEvent * event);
 
-static void 	gst_ivorbisfile_get_property 	(GObject *object, 
-		            			 guint prop_id, 
-						 GValue *value, 
-						 GParamSpec *pspec);
-static void 	gst_ivorbisfile_set_property 	(GObject *object, 
-		            			 guint prop_id, 
-						 const GValue *value, 
-						 GParamSpec *pspec);
+static void gst_ivorbisfile_get_property (GObject * object,
+    guint prop_id, GValue * value, GParamSpec * pspec);
+static void gst_ivorbisfile_set_property (GObject * object,
+    guint prop_id, const GValue * value, GParamSpec * pspec);
 
-static void 	gst_ivorbisfile_loop 		(GstElement *element);
+static void gst_ivorbisfile_loop (GstElement * element);
 
 static GstElementClass *parent_class = NULL;
+
 //static guint gst_ivorbisfile_signals[LAST_SIGNAL] = { 0 };
 
 static GstFormat logical_stream_format;
 
-static GstCaps*
-vorbis_caps_factory (void)
-{
-  return
-   gst_caps_new (
-  	"tremor_tremor",
-  	"application/ogg",
-  	NULL);
-}
-
-static GstCaps*
-raw_caps_factory (void)
-{
-  return
-   gst_caps_new (
-  	"tremor_raw",
-  	"audio/x-raw-int",
-	gst_props_new (
-    	    "endianness", 	GST_PROPS_INT (G_BYTE_ORDER),
-    	    "signed", 		GST_PROPS_BOOLEAN (TRUE),
-    	    "width", 		GST_PROPS_INT (16),
-    	    "depth",    	GST_PROPS_INT (16),
-    	    "rate",     	GST_PROPS_INT_RANGE (11025, 48000),
-    	    "channels", 	GST_PROPS_INT_RANGE (1, 2),
-	    NULL));
-}
-
-static GstCaps*
-raw_caps2_factory (void)
-{
-  return
-   gst_caps_new (
-  	"tremor_raw_float",
-  	"audio/x-raw-float",
-	gst_props_new (
-    	    "depth",		GST_PROPS_INT (32),
-	    "endianness",	GST_PROPS_INT (G_BYTE_ORDER),
-    	    "rate",     	GST_PROPS_INT_RANGE (11025, 48000),
-    	    "channels", 	GST_PROPS_INT (2), /* ?? */
-	    NULL));
-}
-
 GType
 ivorbisfile_get_type (void)
 {
@@ -201,14 +151,50 @@ ivorbisfile_get_type (void)
       (GInstanceInitFunc) gst_ivorbisfile_init,
     };
 
-    ivorbisfile_type = g_type_register_static (GST_TYPE_ELEMENT, "Ivorbisfile", 
-		                              &ivorbisfile_info, 0);
+    ivorbisfile_type = g_type_register_static (GST_TYPE_ELEMENT, "Ivorbisfile",
+        &ivorbisfile_info, 0);
 
-    logical_stream_format = gst_format_register ("logical_stream", "The logical stream");
+    logical_stream_format =
+        gst_format_register ("logical_stream", "The logical stream");
+
+    GST_DEBUG_CATEGORY_INIT (ivorbisfile_debug, "ivorbisfile", 0,
+        "vorbis in ogg decoding element (integer arithmetic)");
   }
   return ivorbisfile_type;
 }
 
+static GstCaps *
+vorbis_caps_factory (void)
+{
+  return gst_caps_new_simple ("application/ogg", NULL);
+
+}
+
+static GstCaps *
+raw_caps_factory (void)
+{
+  return
+      gst_caps_new_simple ("audio/x-raw-int",
+      "endianness", G_TYPE_INT, G_BYTE_ORDER,
+      "signed", G_TYPE_BOOLEAN, TRUE,
+      "width", G_TYPE_INT, 16,
+      "depth", G_TYPE_INT, 16,
+      "rate", GST_TYPE_INT_RANGE, 11025, 48000,
+      "channels", GST_TYPE_INT_RANGE, 1, 2, NULL);
+}
+
+static GstCaps *
+raw_caps2_factory (void)
+{
+  return
+      gst_caps_new_simple ("audio/x-raw-float",
+      "depth", G_TYPE_INT, 32,
+      "endianness", G_TYPE_INT, G_BYTE_ORDER,
+      "rate", GST_TYPE_INT_RANGE, 11025, 48000,
+      "channels", G_TYPE_INT, 2, NULL);
+}
+
+
 static void
 gst_ivorbisfile_base_init (gpointer g_class)
 {
@@ -220,16 +206,16 @@ gst_ivorbisfile_base_init (gpointer g_class)
   vorbis_caps = vorbis_caps_factory ();
 
   /* register sink pads */
-  gst_vorbisdec_sink_template = gst_pad_template_new ("sink", GST_PAD_SINK, 
-		                                      GST_PAD_ALWAYS, 
-					              vorbis_caps, NULL);
-  raw_caps = gst_caps_prepend (raw_caps, raw_caps2);
+  gst_vorbisdec_sink_template = gst_pad_template_new ("sink", GST_PAD_SINK,
+      GST_PAD_ALWAYS, vorbis_caps);
+  gst_caps_append (raw_caps2, raw_caps);
   /* register src pads */
-  gst_vorbisdec_src_template = gst_pad_template_new ("src", GST_PAD_SRC, 
-		                                     GST_PAD_ALWAYS, 
-					             raw_caps, NULL);
-  gst_element_class_add_pad_template (element_class, gst_vorbisdec_sink_template);
-  gst_element_class_add_pad_template (element_class, gst_vorbisdec_src_template);
+  gst_vorbisdec_src_template = gst_pad_template_new ("src", GST_PAD_SRC,
+      GST_PAD_ALWAYS, raw_caps2);
+  gst_element_class_add_pad_template (element_class,
+      gst_vorbisdec_sink_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_vorbisdec_src_template);
   gst_element_class_set_details (element_class, &ivorbisfile_details);
 }
 
@@ -239,17 +225,17 @@ gst_ivorbisfile_class_init (IvorbisfileClass * klass)
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
 
-  gobject_class = (GObjectClass*) klass;
+  gobject_class = (GObjectClass *) klass;
   gstelement_class = (GstElementClass *) klass;
 
   parent_class = g_type_class_ref (GST_TYPE_ELEMENT);
 
   g_object_class_install_property (gobject_class, ARG_METADATA,
-    g_param_spec_boxed ("metadata", "Metadata", "(logical) Stream metadata",
-                         GST_TYPE_CAPS, G_PARAM_READABLE));
+      g_param_spec_boxed ("metadata", "Metadata", "(logical) Stream metadata",
+          GST_TYPE_CAPS, G_PARAM_READABLE));
   g_object_class_install_property (gobject_class, ARG_STREAMINFO,
-    g_param_spec_boxed ("streaminfo", "stream", "(logical) Stream information",
-                         GST_TYPE_CAPS, G_PARAM_READABLE));
+      g_param_spec_boxed ("streaminfo", "stream",
+          "(logical) Stream information", GST_TYPE_CAPS, G_PARAM_READABLE));
 
   gobject_class->get_property = gst_ivorbisfile_get_property;
   gobject_class->set_property = gst_ivorbisfile_set_property;
@@ -261,23 +247,28 @@ static void
 gst_ivorbisfile_init (Ivorbisfile * ivorbisfile)
 {
   ivorbisfile->sinkpad = gst_pad_new_from_template (gst_vorbisdec_sink_template,
-		                                   "sink");
+      "sink");
   gst_element_add_pad (GST_ELEMENT (ivorbisfile), ivorbisfile->sinkpad);
-  gst_pad_set_formats_function (ivorbisfile->sinkpad, gst_ivorbisfile_get_formats);
-  gst_pad_set_convert_function (ivorbisfile->sinkpad, gst_ivorbisfile_sink_convert);
+  gst_pad_set_formats_function (ivorbisfile->sinkpad,
+      gst_ivorbisfile_get_formats);
+  gst_pad_set_convert_function (ivorbisfile->sinkpad,
+      gst_ivorbisfile_sink_convert);
 
-  gst_element_set_loop_function (GST_ELEMENT (ivorbisfile), gst_ivorbisfile_loop);
-  ivorbisfile->srcpad = gst_pad_new_from_template (gst_vorbisdec_src_template, 
-		                                  "src");
+  gst_element_set_loop_function (GST_ELEMENT (ivorbisfile),
+      gst_ivorbisfile_loop);
+  ivorbisfile->srcpad =
+      gst_pad_new_from_template (gst_vorbisdec_src_template, "src");
   gst_element_add_pad (GST_ELEMENT (ivorbisfile), ivorbisfile->srcpad);
-  gst_pad_set_formats_function (ivorbisfile->srcpad, gst_ivorbisfile_get_formats);
-  gst_pad_set_query_type_function (ivorbisfile->srcpad, 
-		                   gst_ivorbisfile_get_query_types);
+  gst_pad_set_formats_function (ivorbisfile->srcpad,
+      gst_ivorbisfile_get_formats);
+  gst_pad_set_query_type_function (ivorbisfile->srcpad,
+      gst_ivorbisfile_get_query_types);
   gst_pad_set_query_function (ivorbisfile->srcpad, gst_ivorbisfile_src_query);
-  gst_pad_set_event_mask_function (ivorbisfile->srcpad, 
-		                   gst_ivorbisfile_get_event_masks);
+  gst_pad_set_event_mask_function (ivorbisfile->srcpad,
+      gst_ivorbisfile_get_event_masks);
   gst_pad_set_event_function (ivorbisfile->srcpad, gst_ivorbisfile_src_event);
-  gst_pad_set_convert_function (ivorbisfile->srcpad, gst_ivorbisfile_src_convert);
+  gst_pad_set_convert_function (ivorbisfile->srcpad,
+      gst_ivorbisfile_src_convert);
 
   ivorbisfile->total_bytes = 0;
   ivorbisfile->offset = 0;
@@ -303,43 +294,42 @@ gst_ivorbisfile_read (void *ptr, size_t size, size_t nmemb, void *datasource)
   GST_DEBUG ("read %d", read_size);
 
   /* make sure we don't go to EOS */
-  if (!ivorbisfile->may_eos && ivorbisfile->total_bytes && 
-       ivorbisfile->offset + read_size > ivorbisfile->total_bytes) 
-  {
+  if (!ivorbisfile->may_eos && ivorbisfile->total_bytes &&
+      ivorbisfile->offset + read_size > ivorbisfile->total_bytes) {
     read_size = ivorbisfile->total_bytes - ivorbisfile->offset;
   }
 
   if (read_size == 0 || ivorbisfile->eos)
     return 0;
-  
+
   while (got_bytes == 0) {
     got_bytes = gst_bytestream_peek_bytes (ivorbisfile->bs, &data, read_size);
     if (got_bytes < read_size) {
       GstEvent *event;
       guint32 avail;
-    
-      gst_bytestream_get_status (ivorbisfile->bs, &avail, &event); 
+
+      gst_bytestream_get_status (ivorbisfile->bs, &avail, &event);
 
       switch (GST_EVENT_TYPE (event)) {
-	case GST_EVENT_EOS:
-	  GST_DEBUG ("eos");
+        case GST_EVENT_EOS:
+          GST_DEBUG ("eos");
           ivorbisfile->eos = TRUE;
           if (avail == 0) {
             gst_event_unref (event);
             return 0;
-	  }
-	  break;
-	case GST_EVENT_DISCONTINUOUS:
-	  GST_DEBUG ("discont");
-	  ivorbisfile->need_discont = TRUE;
-	default:
+          }
+          break;
+        case GST_EVENT_DISCONTINUOUS:
+          GST_DEBUG ("discont");
+          ivorbisfile->need_discont = TRUE;
+        default:
           break;
       }
       gst_event_unref (event);
-      if (avail > 0) 
+      if (avail > 0)
         got_bytes = gst_bytestream_peek_bytes (ivorbisfile->bs, &data, avail);
       else
-	got_bytes = 0;
+        got_bytes = 0;
     }
   }
 
@@ -363,25 +353,22 @@ gst_ivorbisfile_seek (void *datasource, int64_t offset, int whence)
   if (!ivorbisfile->vf.seekable) {
     return -1;
   }
-  
+
   GST_DEBUG ("seek %lld %d", offset, whence);
 
   if (whence == SEEK_SET) {
     method = GST_SEEK_METHOD_SET;
     pending_offset = offset;
-  }
-  else if (whence == SEEK_CUR) {
+  } else if (whence == SEEK_CUR) {
     method = GST_SEEK_METHOD_CUR;
     pending_offset += offset;
-  }
-  else if (whence == SEEK_END) {
+  } else if (whence == SEEK_END) {
     method = GST_SEEK_METHOD_END;
     need_total = TRUE;
     pending_offset = ivorbisfile->total_bytes - offset;
-  }
-  else 
+  } else
     return -1;
-  
+
   if (!gst_bytestream_seek (ivorbisfile->bs, offset, method))
     return -1;
 
@@ -412,19 +399,19 @@ gst_ivorbisfile_tell (void *datasource)
   return result;
 }
 
-ov_callbacks ivorbisfile_ov_callbacks = 
-{
+ov_callbacks ivorbisfile_ov_callbacks = {
   gst_ivorbisfile_read,
   gst_ivorbisfile_seek,
   gst_ivorbisfile_close,
   gst_ivorbisfile_tell,
 };
 
+#if 0
 /* retrieve the comment field (or tags) and put in metadata GstCaps
  * returns TRUE if caps could be set,
  * FALSE if they couldn't be read somehow */
 static gboolean
-gst_ivorbisfile_update_metadata (Ivorbisfile *ivorbisfile, gint link)
+gst_ivorbisfile_update_metadata (Ivorbisfile * ivorbisfile, gint link)
 {
   OggVorbis_File *vf = &ivorbisfile->vf;
   gchar **ptr;
@@ -447,15 +434,14 @@ gst_ivorbisfile_update_metadata (Ivorbisfile *ivorbisfile, gint link)
   while (*ptr) {
     value = strstr (*ptr, "=");
     if (value) {
-      name = g_strndup (*ptr, value-*ptr);
-      entry = gst_props_entry_new (name, GST_PROPS_STRING_TYPE, value+1);
+      name = g_strndup (*ptr, value - *ptr);
+      entry = gst_props_entry_new (name, GST_PROPS_STRING_TYPE, value + 1);
       gst_props_add_entry (props, (GstPropsEntry *) entry);
     }
     ptr++;
   }
   ivorbisfile->metadata = gst_caps_new ("ivorbisfile_metadata",
-		                       "application/x-gst-metadata",
-		                       props);
+      "application/x-gst-metadata", props);
 
   g_object_notify (G_OBJECT (ivorbisfile), "metadata");
 
@@ -466,7 +452,7 @@ gst_ivorbisfile_update_metadata (Ivorbisfile *ivorbisfile, gint link)
  * returns TRUE if caps could be set,
  * FALSE if they couldn't be read somehow */
 static gboolean
-gst_ivorbisfile_update_streaminfo (Ivorbisfile *ivorbisfile, gint link)
+gst_ivorbisfile_update_streaminfo (Ivorbisfile * ivorbisfile, gint link)
 {
   OggVorbis_File *vf = &ivorbisfile->vf;
   vorbis_info *vi;
@@ -485,61 +471,59 @@ gst_ivorbisfile_update_streaminfo (Ivorbisfile *ivorbisfile, gint link)
   vi = ov_info (vf, link);
   entry = gst_props_entry_new ("version", GST_PROPS_INT_TYPE, vi->version);
   gst_props_add_entry (props, (GstPropsEntry *) entry);
-  entry = gst_props_entry_new ("bitrate_upper", GST_PROPS_INT_TYPE, 
-		               vi->bitrate_upper);
+  entry = gst_props_entry_new ("bitrate_upper", GST_PROPS_INT_TYPE,
+      vi->bitrate_upper);
   gst_props_add_entry (props, (GstPropsEntry *) entry);
-  entry = gst_props_entry_new ("bitrate_nominal", GST_PROPS_INT_TYPE, 
-		               vi->bitrate_nominal);
+  entry = gst_props_entry_new ("bitrate_nominal", GST_PROPS_INT_TYPE,
+      vi->bitrate_nominal);
   gst_props_add_entry (props, (GstPropsEntry *) entry);
-  entry = gst_props_entry_new ("bitrate_lower", GST_PROPS_INT_TYPE, 
-		               vi->bitrate_lower);
+  entry = gst_props_entry_new ("bitrate_lower", GST_PROPS_INT_TYPE,
+      vi->bitrate_lower);
   gst_props_add_entry (props, (GstPropsEntry *) entry);
-  entry = gst_props_entry_new ("serial", GST_PROPS_INT_TYPE, 
-		               ov_serialnumber (vf, link));
+  entry = gst_props_entry_new ("serial", GST_PROPS_INT_TYPE,
+      ov_serialnumber (vf, link));
   gst_props_add_entry (props, (GstPropsEntry *) entry);
-  entry = gst_props_entry_new ("bitrate", GST_PROPS_INT_TYPE, 
-		               ov_bitrate (vf, link));
+  entry = gst_props_entry_new ("bitrate", GST_PROPS_INT_TYPE,
+      ov_bitrate (vf, link));
   gst_props_add_entry (props, (GstPropsEntry *) entry);
 
   ivorbisfile->streaminfo = gst_caps_new ("ivorbisfile_streaminfo",
-		                         "application/x-gst-streaminfo",
-		                         props);
+      "application/x-gst-streaminfo", props);
 
   g_object_notify (G_OBJECT (ivorbisfile), "streaminfo");
 
   return TRUE;
 }
+#endif
 
 static gboolean
-gst_ivorbisfile_new_link (Ivorbisfile *ivorbisfile, gint link)
+gst_ivorbisfile_new_link (Ivorbisfile * ivorbisfile, gint link)
 {
   vorbis_info *vi = ov_info (&ivorbisfile->vf, link);
-  GstCaps *newcaps;
+  GstCaps *caps;
+  gboolean res = TRUE;
 
   /* new logical bitstream */
   ivorbisfile->current_link = link;
 
-  gst_ivorbisfile_update_metadata (ivorbisfile, link);
-  gst_ivorbisfile_update_streaminfo (ivorbisfile, link);
+  caps = gst_caps_new_simple ("audio/x-raw-int",
+      "endianness", G_TYPE_INT, G_BYTE_ORDER,
+      "signed", G_TYPE_BOOLEAN, TRUE,
+      "width", G_TYPE_INT, 16,
+      "depth", G_TYPE_INT, 16,
+      "rate", G_TYPE_INT, vi->rate, "channels", G_TYPE_INT, vi->channels, NULL);
 
-  newcaps = GST_CAPS_NEW ("vorbisdec_src",
-                          "audio/x-raw-int",    
-                            "endianness", GST_PROPS_INT (G_BYTE_ORDER),
-                            "signed",     GST_PROPS_BOOLEAN (TRUE),
-                            "width",      GST_PROPS_INT (16),
-                            "depth",      GST_PROPS_INT (16),
-                            "rate",       GST_PROPS_INT (vi->rate),
-                            "channels",   GST_PROPS_INT (vi->channels)
-                          );
-  if (gst_pad_try_set_caps (ivorbisfile->srcpad, newcaps) <= 0) {
-     return FALSE;
+  if (gst_pad_try_set_caps (ivorbisfile->srcpad, caps) <= 0) {
+    res = FALSE;
   }
 
+  gst_caps_free (caps);
+
   return TRUE;
 }
 
 static void
-gst_ivorbisfile_loop (GstElement *element)
+gst_ivorbisfile_loop (GstElement * element)
 {
   Ivorbisfile *ivorbisfile = GST_IVORBISFILE (element);
   GstBuffer *outbuf;
@@ -554,15 +538,15 @@ gst_ivorbisfile_loop (GstElement *element)
     ivorbisfile->offset = 0;
     ivorbisfile->total_bytes = 0;
     ivorbisfile->may_eos = FALSE;
-    ivorbisfile->vf.seekable = gst_bytestream_seek (ivorbisfile->bs, 0, 
-		                                   GST_SEEK_METHOD_SET);
+    ivorbisfile->vf.seekable = gst_bytestream_seek (ivorbisfile->bs, 0,
+        GST_SEEK_METHOD_SET);
     GST_DEBUG ("ivorbisfile: seekable: %s\n",
-	       ivorbisfile->vf.seekable ? "yes" : "no");
+        ivorbisfile->vf.seekable ? "yes" : "no");
 
     /* open our custom ivorbisfile data object with the callbacks we provide */
-    if (ov_open_callbacks (ivorbisfile, &ivorbisfile->vf, NULL, 0, 
-			   ivorbisfile_ov_callbacks) < 0) {
-      gst_element_error (element, "this is not a vorbis file");
+    if (ov_open_callbacks (ivorbisfile, &ivorbisfile->vf, NULL, 0,
+            ivorbisfile_ov_callbacks) < 0) {
+      GST_ELEMENT_ERROR (element, STREAM, DECODE, (NULL), (NULL));
       return;
     }
     ivorbisfile->need_discont = TRUE;
@@ -578,47 +562,43 @@ gst_ivorbisfile_loop (GstElement *element)
       {
         gdouble seek_to = (gdouble) ivorbisfile->seek_value / GST_SECOND;
 
-	if (ivorbisfile->seek_accurate) {
+        if (ivorbisfile->seek_accurate) {
           if (ov_time_seek (&ivorbisfile->vf, seek_to) == 0) {
             ivorbisfile->need_discont = TRUE;
           }
-        }
-	else {
+        } else {
           if (ov_time_seek_page (&ivorbisfile->vf, seek_to) == 0) {
             ivorbisfile->need_discont = TRUE;
           }
-	}
-	break;
+        }
+        break;
       }
       case GST_FORMAT_DEFAULT:
-	if (ivorbisfile->seek_accurate) {
+        if (ivorbisfile->seek_accurate) {
           if (ov_pcm_seek (&ivorbisfile->vf, ivorbisfile->seek_value) == 0) {
             ivorbisfile->need_discont = TRUE;
           }
-        }
-	else {
+        } else {
           if (ov_pcm_seek_page (&ivorbisfile->vf, ivorbisfile->seek_value) == 0) {
             ivorbisfile->need_discont = TRUE;
           }
-	}
-	break;
+        }
+        break;
       default:
-	if (ivorbisfile->seek_format == logical_stream_format) {
+        if (ivorbisfile->seek_format == logical_stream_format) {
           gint64 seek_to;
-	  
-	  seek_to = ivorbisfile->vf.offsets[ivorbisfile->seek_value];
+
+          seek_to = ivorbisfile->vf.offsets[ivorbisfile->seek_value];
 
           if (ov_raw_seek (&ivorbisfile->vf, seek_to) == 0) {
             ivorbisfile->need_discont = TRUE;
             ivorbisfile->current_link = -1;
+          } else {
+            g_warning ("raw seek failed");
           }
-	  else {
-	    g_warning ("raw seek failed");
-	  }
-	}
-	else
-	  g_warning ("unknown seek method, implement me !");
-	break;
+        } else
+          g_warning ("unknown seek method, implement me !");
+        break;
     }
     ivorbisfile->seek_pending = FALSE;
   }
@@ -626,7 +606,7 @@ gst_ivorbisfile_loop (GstElement *element)
   /* we update the caps for each logical stream */
   if (ivorbisfile->vf.current_link != ivorbisfile->current_link) {
     if (!gst_ivorbisfile_new_link (ivorbisfile, ivorbisfile->vf.current_link)) {
-      gst_element_error (GST_ELEMENT (ivorbisfile), "could not negotiate format");
+      GST_ELEMENT_ERROR (ivorbisfile, CORE, NEGOTIATION, (NULL), (NULL));
     }
     return;
   }
@@ -638,30 +618,27 @@ gst_ivorbisfile_loop (GstElement *element)
   /* get current time for discont and buffer timestamp */
   time = (GstClockTime) (ov_time_tell (&ivorbisfile->vf) * GST_SECOND);
 
-  ret = ov_read (&ivorbisfile->vf, 
-		 GST_BUFFER_DATA (outbuf), GST_BUFFER_SIZE (outbuf), 
-		 &link);
+  ret = ov_read (&ivorbisfile->vf,
+      GST_BUFFER_DATA (outbuf), GST_BUFFER_SIZE (outbuf), &link);
 
   if (ret == 0) {
     GST_DEBUG ("eos");
     /* send EOS event */
-    /*ov_clear (&ivorbisfile->vf);*/
+    /*ov_clear (&ivorbisfile->vf); */
     ivorbisfile->restart = TRUE;
     gst_buffer_unref (outbuf);
     /* if the pad is not usable, don't push it out */
     if (GST_PAD_IS_USABLE (ivorbisfile->srcpad)) {
-      gst_pad_push (ivorbisfile->srcpad, 
-		    GST_DATA (gst_event_new (GST_EVENT_EOS)));
+      gst_pad_push (ivorbisfile->srcpad,
+          GST_DATA (gst_event_new (GST_EVENT_EOS)));
     }
     gst_element_set_eos (element);
     return;
-  }
-  else if (ret < 0) {
+  } else if (ret < 0) {
     g_warning ("ivorbisfile: decoding error");
     gst_buffer_unref (outbuf);
     return;
-  }
-  else {
+  } else {
     if (ivorbisfile->need_discont) {
       GstEvent *discont;
 
@@ -672,8 +649,8 @@ gst_ivorbisfile_loop (GstElement *element)
         /* get stream stats */
         samples = (gint64) (ov_pcm_tell (&ivorbisfile->vf));
 
-        discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, time, 
-		    			     GST_FORMAT_DEFAULT, samples, NULL); 
+        discont = gst_event_new_discontinuous (FALSE, GST_FORMAT_TIME, time,
+            GST_FORMAT_DEFAULT, samples, NULL);
 
         gst_pad_push (ivorbisfile->srcpad, GST_DATA (discont));
       }
@@ -687,16 +664,16 @@ gst_ivorbisfile_loop (GstElement *element)
     if (!ivorbisfile->vf.seekable) {
       ivorbisfile->total_bytes += GST_BUFFER_SIZE (outbuf);
     }
-  
-    if (GST_PAD_IS_USABLE (ivorbisfile->srcpad)) 
+
+    if (GST_PAD_IS_USABLE (ivorbisfile->srcpad))
       gst_pad_push (ivorbisfile->srcpad, GST_DATA (outbuf));
     else
       gst_buffer_unref (outbuf);
   }
 }
 
-static const GstFormat*
-gst_ivorbisfile_get_formats (GstPad *pad)
+static const GstFormat *
+gst_ivorbisfile_get_formats (GstPad * pad)
 {
   static GstFormat src_formats[] = {
     GST_FORMAT_TIME,
@@ -714,21 +691,21 @@ gst_ivorbisfile_get_formats (GstPad *pad)
 
   src_formats[3] = logical_stream_format;
   sink_formats[2] = logical_stream_format;
-  
+
   return (GST_PAD_IS_SRC (pad) ? src_formats : sink_formats);
 }
 
 static gboolean
-gst_ivorbisfile_src_convert (GstPad *pad, 
-		            GstFormat src_format, gint64 src_value,
-		            GstFormat *dest_format, gint64 *dest_value)
+gst_ivorbisfile_src_convert (GstPad * pad,
+    GstFormat src_format, gint64 src_value,
+    GstFormat * dest_format, gint64 * dest_value)
 {
   gboolean res = TRUE;
   guint scale = 1;
   gint bytes_per_sample;
-  Ivorbisfile *ivorbisfile; 
+  Ivorbisfile *ivorbisfile;
   vorbis_info *vi;
-  
+
   ivorbisfile = GST_IVORBISFILE (gst_pad_get_parent (pad));
 
   vi = ov_info (&ivorbisfile->vf, -1);
@@ -755,12 +732,12 @@ gst_ivorbisfile_src_convert (GstPad *pad,
     case GST_FORMAT_DEFAULT:
       switch (*dest_format) {
         case GST_FORMAT_BYTES:
-	  *dest_value = src_value * bytes_per_sample;
+          *dest_value = src_value * bytes_per_sample;
           break;
         case GST_FORMAT_TIME:
-	  if (vi->rate == 0)
-	    return FALSE;
-	  *dest_value = src_value * GST_SECOND / vi->rate;
+          if (vi->rate == 0)
+            return FALSE;
+          *dest_value = src_value * GST_SECOND / vi->rate;
           break;
         default:
           res = FALSE;
@@ -769,9 +746,9 @@ gst_ivorbisfile_src_convert (GstPad *pad,
     case GST_FORMAT_TIME:
       switch (*dest_format) {
         case GST_FORMAT_BYTES:
-	  scale = bytes_per_sample;
+          scale = bytes_per_sample;
         case GST_FORMAT_DEFAULT:
-	  *dest_value = src_value * scale * vi->rate / GST_SECOND;
+          *dest_value = src_value * scale * vi->rate / GST_SECOND;
           break;
         default:
           res = FALSE;
@@ -779,47 +756,47 @@ gst_ivorbisfile_src_convert (GstPad *pad,
       break;
     default:
       if (src_format == logical_stream_format) {
-	/* because we need to convert relative from 0, we have to add
-	 * all pcm totals */
-	gint i;
-	gint64 count = 0;
+        /* because we need to convert relative from 0, we have to add
+         * all pcm totals */
+        gint i;
+        gint64 count = 0;
 
         switch (*dest_format) {
           case GST_FORMAT_BYTES:
             res = FALSE;
             break;
           case GST_FORMAT_DEFAULT:
-	    if (src_value > ivorbisfile->vf.links) {
-	      src_value = ivorbisfile->vf.links;
-	    }
-	    for (i = 0; i < src_value; i++) {
-	      vi = ov_info (&ivorbisfile->vf, i);
+            if (src_value > ivorbisfile->vf.links) {
+              src_value = ivorbisfile->vf.links;
+            }
+            for (i = 0; i < src_value; i++) {
+              vi = ov_info (&ivorbisfile->vf, i);
 
-	      count += ov_pcm_total (&ivorbisfile->vf, i);
-	    }
-	    *dest_value = count;
+              count += ov_pcm_total (&ivorbisfile->vf, i);
+            }
+            *dest_value = count;
             break;
           case GST_FORMAT_TIME:
-	  {
-	    if (src_value > ivorbisfile->vf.links) {
-	      src_value = ivorbisfile->vf.links;
-	    }
-	    for (i = 0; i < src_value; i++) {
-	      vi = ov_info (&ivorbisfile->vf, i);
-	      if (vi->rate) 
-	        count += ov_pcm_total (&ivorbisfile->vf, i) * GST_SECOND / vi->rate;
-	      else
-	        count += ov_time_total (&ivorbisfile->vf, i) * GST_SECOND;
-	    }
-	    /* we use the pcm totals to get the total time, it's more accurate */
-	    *dest_value = count;
+          {
+            if (src_value > ivorbisfile->vf.links) {
+              src_value = ivorbisfile->vf.links;
+            }
+            for (i = 0; i < src_value; i++) {
+              vi = ov_info (&ivorbisfile->vf, i);
+              if (vi->rate)
+                count +=
+                    ov_pcm_total (&ivorbisfile->vf, i) * GST_SECOND / vi->rate;
+              else
+                count += ov_time_total (&ivorbisfile->vf, i) * GST_SECOND;
+            }
+            /* we use the pcm totals to get the total time, it's more accurate */
+            *dest_value = count;
             break;
-	  }
+          }
           default:
             res = FALSE;
-	}
-      }
-      else
+        }
+      } else
         res = FALSE;
       break;
   }
@@ -827,13 +804,13 @@ gst_ivorbisfile_src_convert (GstPad *pad,
 }
 
 static gboolean
-gst_ivorbisfile_sink_convert (GstPad *pad, 
-		             GstFormat src_format, gint64 src_value,
-		             GstFormat *dest_format, gint64 *dest_value)
+gst_ivorbisfile_sink_convert (GstPad * pad,
+    GstFormat src_format, gint64 src_value,
+    GstFormat * dest_format, gint64 * dest_value)
 {
   gboolean res = TRUE;
-  Ivorbisfile *ivorbisfile; 
-  
+  Ivorbisfile *ivorbisfile;
+
   ivorbisfile = GST_IVORBISFILE (gst_pad_get_parent (pad));
 
   switch (src_format) {
@@ -843,8 +820,7 @@ gst_ivorbisfile_sink_convert (GstPad *pad,
           break;
         default:
           if (*dest_format == logical_stream_format) {
-          }
-	  else
+          } else
             res = FALSE;
       }
     case GST_FORMAT_TIME:
@@ -853,8 +829,7 @@ gst_ivorbisfile_sink_convert (GstPad *pad,
           break;
         default:
           if (*dest_format == logical_stream_format) {
-          }
-	  else
+          } else
             res = FALSE;
       }
     default:
@@ -867,8 +842,7 @@ gst_ivorbisfile_sink_convert (GstPad *pad,
           default:
             res = FALSE;
         }
-      }
-      else
+      } else
         res = FALSE;
       break;
   }
@@ -876,8 +850,8 @@ gst_ivorbisfile_sink_convert (GstPad *pad,
   return res;
 }
 
-static const GstQueryType*
-gst_ivorbisfile_get_query_types (GstPad *pad)
+static const GstQueryType *
+gst_ivorbisfile_get_query_types (GstPad * pad)
 {
   static const GstQueryType types[] = {
     GST_QUERY_TOTAL,
@@ -889,13 +863,13 @@ gst_ivorbisfile_get_query_types (GstPad *pad)
 
 /* handles queries for location in the stream in the requested format */
 static gboolean
-gst_ivorbisfile_src_query (GstPad *pad, GstQueryType type,
-		          GstFormat *format, gint64 *value)
+gst_ivorbisfile_src_query (GstPad * pad, GstQueryType type,
+    GstFormat * format, gint64 * value)
 {
   gboolean res = TRUE;
-  Ivorbisfile *ivorbisfile; 
+  Ivorbisfile *ivorbisfile;
   vorbis_info *vi;
-  
+
   ivorbisfile = GST_IVORBISFILE (gst_pad_get_parent (pad));
 
   vi = ov_info (&ivorbisfile->vf, -1);
@@ -906,30 +880,30 @@ gst_ivorbisfile_src_query (GstPad *pad, GstQueryType type,
       switch (*format) {
         case GST_FORMAT_DEFAULT:
           if (ivorbisfile->vf.seekable)
-	    *value = ov_pcm_total (&ivorbisfile->vf, -1);
-	  else
-	    return FALSE;
-	  break;
+            *value = ov_pcm_total (&ivorbisfile->vf, -1);
+          else
+            return FALSE;
+          break;
         case GST_FORMAT_BYTES:
           if (ivorbisfile->vf.seekable)
-	    *value = ov_pcm_total (&ivorbisfile->vf, -1) * vi->channels * 2;
-	  else
-	    return FALSE;
-	  break;
+            *value = ov_pcm_total (&ivorbisfile->vf, -1) * vi->channels * 2;
+          else
+            return FALSE;
+          break;
         case GST_FORMAT_TIME:
           if (ivorbisfile->vf.seekable)
-	    *value = (gint64) (ov_time_total (&ivorbisfile->vf, -1) * GST_SECOND);
-	  else
-	    return FALSE;
-	  break;
-	default:
-	  if (*format == logical_stream_format) {
+            *value =
+                (gint64) (ov_time_total (&ivorbisfile->vf, -1) * GST_SECOND);
+          else
+            return FALSE;
+          break;
+        default:
+          if (*format == logical_stream_format) {
             if (ivorbisfile->vf.seekable)
-	      *value = ivorbisfile->vf.links;
-	    else
-	     return FALSE;
-	  }
-	  else
+              *value = ivorbisfile->vf.links;
+            else
+              return FALSE;
+          } else
             res = FALSE;
           break;
       }
@@ -939,31 +913,30 @@ gst_ivorbisfile_src_query (GstPad *pad, GstQueryType type,
       switch (*format) {
         case GST_FORMAT_TIME:
           if (ivorbisfile->vf.seekable)
-	    *value = (gint64) (ov_time_tell (&ivorbisfile->vf) * GST_SECOND);
-	  else
-            *value = ivorbisfile->total_bytes * GST_SECOND 
-		                             / (vi->rate * vi->channels * 2);
-	  break;
+            *value = (gint64) (ov_time_tell (&ivorbisfile->vf) * GST_SECOND);
+          else
+            *value = ivorbisfile->total_bytes * GST_SECOND
+                / (vi->rate * vi->channels * 2);
+          break;
         case GST_FORMAT_BYTES:
           if (ivorbisfile->vf.seekable)
-	    *value = ov_pcm_tell (&ivorbisfile->vf) * vi->channels * 2;
-	  else
+            *value = ov_pcm_tell (&ivorbisfile->vf) * vi->channels * 2;
+          else
             *value = ivorbisfile->total_bytes;
-	  break;
+          break;
         case GST_FORMAT_DEFAULT:
           if (ivorbisfile->vf.seekable)
-	    *value = ov_pcm_tell (&ivorbisfile->vf);
-	  else
+            *value = ov_pcm_tell (&ivorbisfile->vf);
+          else
             *value = ivorbisfile->total_bytes / (vi->channels * 2);
-	  break;
+          break;
         default:
-	  if (*format == logical_stream_format) {
+          if (*format == logical_stream_format) {
             if (ivorbisfile->vf.seekable)
-	      *value = ivorbisfile->current_link;
-	    else
-	     return FALSE;
-	  }
-	  else
+              *value = ivorbisfile->current_link;
+            else
+              return FALSE;
+          } else
             res = FALSE;
           break;
       }
@@ -976,23 +949,23 @@ gst_ivorbisfile_src_query (GstPad *pad, GstQueryType type,
   return res;
 }
 
-static const GstEventMask*
-gst_ivorbisfile_get_event_masks (GstPad *pad)
+static const GstEventMask *
+gst_ivorbisfile_get_event_masks (GstPad * pad)
 {
   static const GstEventMask masks[] = {
-    { GST_EVENT_SEEK, GST_SEEK_METHOD_SET | GST_SEEK_FLAG_ACCURATE },
-    { 0, }
+    {GST_EVENT_SEEK, GST_SEEK_METHOD_SET | GST_SEEK_FLAG_ACCURATE},
+    {0,}
   };
   return masks;
 }
 
 /* handle events on src pad */
 static gboolean
-gst_ivorbisfile_src_event (GstPad *pad, GstEvent *event)
+gst_ivorbisfile_src_event (GstPad * pad, GstEvent * event)
 {
   gboolean res = TRUE;
-  Ivorbisfile *ivorbisfile; 
-		  
+  Ivorbisfile *ivorbisfile;
+
   ivorbisfile = GST_IVORBISFILE (gst_pad_get_parent (pad));
 
   switch (GST_EVENT_TYPE (event)) {
@@ -1001,12 +974,12 @@ gst_ivorbisfile_src_event (GstPad *pad, GstEvent *event)
       gint64 offset;
       vorbis_info *vi;
       GstFormat format;
-  
+
       GST_DEBUG ("ivorbisfile: handling seek event on pad %s:%s",
-		 GST_DEBUG_PAD_NAME (pad));
+          GST_DEBUG_PAD_NAME (pad));
       if (!ivorbisfile->vf.seekable) {
-	gst_event_unref (event);
-	GST_DEBUG ("vorbis stream is not seekable");
+        gst_event_unref (event);
+        GST_DEBUG ("vorbis stream is not seekable");
         return FALSE;
       }
 
@@ -1014,43 +987,41 @@ gst_ivorbisfile_src_event (GstPad *pad, GstEvent *event)
       format = GST_EVENT_SEEK_FORMAT (event);
 
       switch (format) {
-	case GST_FORMAT_TIME:
-	  ivorbisfile->seek_pending = TRUE;
-	  ivorbisfile->seek_value = offset;
-	  ivorbisfile->seek_format = format;
-	  ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event) 
-		                    & GST_SEEK_FLAG_ACCURATE;
-	  break;
-	case GST_FORMAT_BYTES:
+        case GST_FORMAT_TIME:
+          ivorbisfile->seek_pending = TRUE;
+          ivorbisfile->seek_value = offset;
+          ivorbisfile->seek_format = format;
+          ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event)
+              & GST_SEEK_FLAG_ACCURATE;
+          break;
+        case GST_FORMAT_BYTES:
           vi = ov_info (&ivorbisfile->vf, -1);
-	  if (vi->channels == 0) {
-	    GST_DEBUG ("vorbis stream has 0 channels ?");
-	    res = FALSE;
-	    goto done; 
-	  }
+          if (vi->channels == 0) {
+            GST_DEBUG ("vorbis stream has 0 channels ?");
+            res = FALSE;
+            goto done;
+          }
           offset /= vi->channels * 2;
-	  /* fallthrough */
-	case GST_FORMAT_DEFAULT:
-	  ivorbisfile->seek_pending = TRUE;
-	  ivorbisfile->seek_value = offset;
-	  ivorbisfile->seek_format = format;
-	  ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event) 
-		                    & GST_SEEK_FLAG_ACCURATE;
-	  break;
-	default:
-	  if (format == logical_stream_format) {
-	    ivorbisfile->seek_pending = TRUE;
-	    ivorbisfile->seek_value = offset;
-	    ivorbisfile->seek_format = format;
-	    ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event) 
-		                      & GST_SEEK_FLAG_ACCURATE;
-	  }
-	  else
-	  {
-	    GST_DEBUG ("unhandled seek format");
-	    res = FALSE;
-	  }
-	  break;
+          /* fallthrough */
+        case GST_FORMAT_DEFAULT:
+          ivorbisfile->seek_pending = TRUE;
+          ivorbisfile->seek_value = offset;
+          ivorbisfile->seek_format = format;
+          ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event)
+              & GST_SEEK_FLAG_ACCURATE;
+          break;
+        default:
+          if (format == logical_stream_format) {
+            ivorbisfile->seek_pending = TRUE;
+            ivorbisfile->seek_value = offset;
+            ivorbisfile->seek_format = format;
+            ivorbisfile->seek_accurate = GST_EVENT_SEEK_FLAGS (event)
+                & GST_SEEK_FLAG_ACCURATE;
+          } else {
+            GST_DEBUG ("unhandled seek format");
+            res = FALSE;
+          }
+          break;
       }
       break;
     }
@@ -1065,10 +1036,10 @@ done:
 }
 
 static GstElementStateReturn
-gst_ivorbisfile_change_state (GstElement *element)
+gst_ivorbisfile_change_state (GstElement * element)
 {
   Ivorbisfile *ivorbisfile = GST_IVORBISFILE (element);
-  
+
   switch (GST_STATE_TRANSITION (element)) {
     case GST_STATE_NULL_TO_READY:
     case GST_STATE_READY_TO_PAUSED:
@@ -1090,16 +1061,16 @@ gst_ivorbisfile_change_state (GstElement *element)
 
   if (GST_ELEMENT_CLASS (parent_class)->change_state)
     return GST_ELEMENT_CLASS (parent_class)->change_state (element);
-  
+
   return GST_STATE_SUCCESS;
 }
 
 static void
-gst_ivorbisfile_set_property (GObject *object, guint prop_id, 
-		             const GValue *value, GParamSpec *pspec)
+gst_ivorbisfile_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
 {
   Ivorbisfile *ivorbisfile;
-	      
+
   g_return_if_fail (GST_IS_IVORBISFILE (object));
 
   ivorbisfile = GST_IVORBISFILE (object);
@@ -1110,12 +1081,12 @@ gst_ivorbisfile_set_property (GObject *object, guint prop_id,
   }
 }
 
-static void 
-gst_ivorbisfile_get_property (GObject *object, guint prop_id, 
-		             GValue *value, GParamSpec *pspec)
+static void
+gst_ivorbisfile_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec)
 {
   Ivorbisfile *ivorbisfile;
-	      
+
   g_return_if_fail (GST_IS_IVORBISFILE (object));
 
   ivorbisfile = GST_IVORBISFILE (object);
