@@ -24,10 +24,10 @@
 #include "vorbisenc.h"
 #include "vorbisdec.h"
 
-extern GType vorbisfile_get_type(void);
+GST_DEBUG_CATEGORY (vorbisdec_debug);
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
   if (!gst_library_load ("gstbytestream"))
     return FALSE;
@@ -35,25 +35,21 @@ plugin_init (GstPlugin *plugin)
   if (!gst_library_load ("gsttags"))
     return FALSE;
 
-  if (!gst_element_register (plugin, "vorbisenc", GST_RANK_NONE, GST_TYPE_VORBISENC))
+  if (!gst_element_register (plugin, "vorbisenc", GST_RANK_NONE,
+          GST_TYPE_VORBISENC))
     return FALSE;
 
-  if (!gst_element_register (plugin, "vorbisfile", GST_RANK_SECONDARY, vorbisfile_get_type ()))
-    return FALSE;
-
-  if (!gst_element_register (plugin, "vorbisdec", GST_RANK_PRIMARY, gst_vorbis_dec_get_type ()))
+  if (!gst_element_register (plugin, "vorbisdec", GST_RANK_PRIMARY,
+          gst_vorbis_dec_get_type ()))
     return FALSE;
 
+  GST_DEBUG_CATEGORY_INIT (vorbisdec_debug, "vorbisdec", 0,
+      "vorbis decoding element");
   return TRUE;
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "vorbis",
-  "Vorbis plugin library",
-  plugin_init,
-  VERSION,
-  "LGPL",
-  GST_PACKAGE,
-  GST_ORIGIN)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "vorbis",
+    "Vorbis plugin library",
+    plugin_init, VERSION, "LGPL", GST_PACKAGE, GST_ORIGIN)
