@@ -26,13 +26,13 @@
 #include "gstrfc2250enc.h"
 
 static gboolean
-plugin_init (GstPlugin *plugin)
+plugin_init (GstPlugin * plugin)
 {
   /* short-circuit here; this is potentially dangerous since if the second
    * or third init fails then the whole plug-in will be placed on the register
    * stack again and the first _init will be called more than once
    * and wtay wants to use dlclose at some point in the future */
-  
+
   if (!gst_library_load ("gstbytestream"))
     return FALSE;
 
@@ -44,15 +44,8 @@ plugin_init (GstPlugin *plugin)
   return TRUE;
 }
 
-GST_PLUGIN_DEFINE (
-  GST_VERSION_MAJOR,
-  GST_VERSION_MINOR,
-  "mpegstream",
-  "MPEG system stream parser",
-  plugin_init,
-  VERSION,
-  "LGPL",
-  GST_COPYRIGHT,
-  GST_PACKAGE,
-  GST_ORIGIN
-)
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    "mpegstream",
+    "MPEG system stream parser",
+    plugin_init, VERSION, "LGPL", GST_PACKAGE, GST_ORIGIN)
